@@ -7,7 +7,6 @@
 namespace ui {
 enum class AvatarType
 {
-        Icon,
         Image,
         Letter
 };
@@ -78,7 +77,7 @@ class Theme : public QObject
 {
         Q_OBJECT
 public:
-        explicit Theme(QObject *parent = 0);
+        explicit Theme(QObject *parent = nullptr);
 
         QColor getColor(const QString &key) const;
 
